@@ -105,8 +105,10 @@ class Command(BaseCommand):
                             "on_white",
                             attrs=["bold", "underline"],
                         )
-                   
-                        result = func()
+                        try:
+                            result = func()
+                        except Exception as ee:
+                            logger.error(ee)
             except Exception as e:
                 continue
                 
@@ -116,7 +118,7 @@ def attachSettings(settingsDict, iunoSiteDomainNames=None):
     It must be called in settings by passing locals().
 
     @param settingsDict locals() in settings.py.
-    @param iunoSiteDomainNames if have IUNO_SITE_DOMAIN_NAMES
+    @param allowedHosts if have IUNO_SITE_DOMAIN_NAMES
     """
     # add ALLOWED_HOSTS by IUNO_SITE_DOMAIN_NAMES while in STAGE/PRODUCTION
     try:       
